summaryrefslogtreecommitdiff
path: root/contrib/lisp/org-track.el
diff options
context:
space:
mode:
Diffstat (limited to 'contrib/lisp/org-track.el')
-rw-r--r--contrib/lisp/org-track.el33
1 files changed, 13 insertions, 20 deletions
diff --git a/contrib/lisp/org-track.el b/contrib/lisp/org-track.el
index 1d12862..db8c34e 100644
--- a/contrib/lisp/org-track.el
+++ b/contrib/lisp/org-track.el
@@ -1,6 +1,6 @@
;;; org-track.el --- Track the most recent Org-mode version available.
;;
-;; Copyright (C) 2009-2012
+;; Copyright (C) 2009-2013
;; Free Software Foundation, Inc.
;;
;; Author: Bastien Guerry <bzg at altern dot org>
@@ -16,12 +16,12 @@
;;
;; This file is not part of GNU Emacs.
;;
-;; GNU Emacs is free software: you can redistribute it and/or modify
+;; This program is free software: you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.
-;; GNU Emacs is distributed in the hope that it will be useful,
+;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
;; GNU General Public License for more details.
@@ -32,6 +32,9 @@
;;
;;; Commentary:
;;
+;; WARNING: This library is obsolete, you should use the make targets
+;; to keep track of Org latest developments.
+;;
;; Download the latest development tarball, unpack and optionally compile it
;;
;; Usage:
@@ -46,15 +49,11 @@
;;
;; M-x org-track-update RET
-
-
(require 'url-parse)
(require 'url-handlers)
(autoload 'url-file-local-copy "url-handlers")
(autoload 'url-generic-parse-url "url-parse")
-
-
;;; Variables:
@@ -66,21 +65,20 @@ To use org-track, adjust `org-track-directory'.
Org will download the archived latest git version for you,
unpack it into that directory (i.e. a subdirectory
`org-mode/' is added), create the autoloads file
-`org-install.el' for you and, optionally, compile the
+`org-loaddefs.el' for you and, optionally, compile the
sources.
All you'll have to do is call `M-x org-track-update' from
time to time."
- :version "22.1"
:group 'org)
-(defcustom org-track-directory "~/.emacs.d/org/lisp"
+(defcustom org-track-directory (concat user-emacs-directory "org/lisp")
"Directory where your org-mode/ directory lives.
If that directory does not exist, it will be created."
:type 'directory)
(defcustom org-track-compile-sources t
"If `nil', never compile org-sources.
-Org will only create the autoloads file `org-install.el' for
+Org will only create the autoloads file `org-loaddefs.el' for
you then. If `t', compile the sources, too.
Note, that emacs preferes compiled elisp files over
non-compiled ones."
@@ -102,8 +100,6 @@ you need to unpack it."
"Remove org-latest.tar.gz after updates?"
:type 'boolean)
-
-
;;; Frontend
@@ -131,7 +127,6 @@ Also, generate autoloads and evtl. compile the sources."
(org-track-compile-org))
(error (message "%s" (error-message-string err)))))))
-
;;; tar related functions
@@ -171,7 +166,6 @@ subdirectory org-mode/ to DIRECTORY."
(if org-track-remove-package
(delete-file target))))
-
;;; Compile Org-mode sources
@@ -180,7 +174,7 @@ subdirectory org-mode/ to DIRECTORY."
;;;###autoload
(defun org-track-compile-org (&optional directory)
"Compile all *.el files that come with org-mode.
-Generate the autoloads file `org-install.el'.
+Generate the autoloads file `org-loaddefs.el'.
DIRECTORY is where the directory org-mode/ lives (i.e. the
parent directory of your local repo."
@@ -193,15 +187,15 @@ DIRECTORY is where the directory org-mode/ lives (i.e. the
"/")))
(add-to-list 'load-path directory)
(let ((list-of-org-files (file-expand-wildcards (concat directory "*.el"))))
;; create the org-install file
(require 'autoload)
- (setq esf/org-install-file (concat directory "org-install.el"))
+ (setq esf/org-install-file (concat directory "org-loaddefs.el"))
(find-file esf/org-install-file)
(erase-buffer)
(mapc (lambda (x)
(generate-file-autoloads x))
list-of-org-files)
- (insert "\n(provide (quote org-install))\n")
+ (insert "\n(provide (quote org-loaddefs))\n")
(save-buffer)
(kill-buffer)
(byte-compile-file esf/org-install-file t)
@@ -213,7 +207,6 @@ DIRECTORY is where the directory org-mode/ lives (i.e. the
(if org-track-compile-sources
(mapc (lambda (f) (byte-compile-file f)) list-of-org-files))))
-
(provide 'org-track)
;;; org-track.el ends here
@@ -193,15 +187,15 @@ DIRECTORY is where the directory org-mode/ lives (i.e. the
(add-to-list 'load-path directory)
(let ((list-of-org-files (file-expand-wildcards (concat directory "*.el"))))
- ;; create the org-install file
+ ;; create the org-loaddefs file
(require 'autoload)